@@ -2,6 +2,7 @@ import logging
 import traceback
 
 import ssl
+from typing import Optional
 
 from pypsql_api.config.types import Session
 from pypsql_api.wire.actions_types import Names
@@ -29,16 +30,30 @@ cipher_list = "ECDH+ECDSA+AESGCM:" \
               "!aNULL:!MD5:!DSS:"
 
 
+def reset(io: ReadingIO) -> ReadingIO:
+    io.buff.seek(0)
+
+
 def read_ssl_request(context: Context):
     logging.error("read_ssl_requst")
     try:
-        ssl_request = SSLRequest.read(context.input)
-        logging.error(ssl_request)
+        # Add support for ancient ssl protocol
+        # New protocol SSLReq, SSLAns, StartupMsg
+        # Ancient: StartupMsg
 
-        if context.key_file and context.cert_file:
-            return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_YES
+        ssl_request = SSLRequest.read(context.input)
+
+        if ssl_request.request_code == 196608:
+            # ancient mode
+            return read_startup_message(context, inner_buff=reset(ssl_request.inner_buff))
         else:
-            return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_NO
+            logging.error(ssl_request)
+
+            if context.key_file and context.cert_file:
+                return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_YES
+            else:
+                return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_NO
+
     except Exception as e:
         log_exception(e)
         logging.error("Error while processing ssl request, downgrading to SSL_NO")
@@ -72,9 +87,11 @@ def write_ssl_resp_yes(context: Context):
     return context, Names.READ_STARTUP_MESSAGE
 
 
-def read_startup_message(context: Context):
+def read_startup_message(context: Context, inner_buff: Optional[ReadingIO] = None):
     try:
-        startup_front = StartupMessage.read(context.input)
+
+        startup_front = StartupMessage.read(context.input) if inner_buff is None else StartupMessage.read_from_buff(
+            inner_buff)
 
         print(f"Got startup  {startup_front}")
 
