@@ -16,11 +16,12 @@ def parse_portal_name(portal_name: str) -> str:
 @dataclass
 class SSLRequest:
     request_code: int
+    inner_buff: Optional[ReadingIO]
 
     @staticmethod
     def read(buff: ReadingIO):
         inner_buff, message_len = buff.read_int32_delim_message()
-        return SSLRequest(request_code=inner_buff.read_int32())
+        return SSLRequest(request_code=inner_buff.read_int32(), inner_buff=inner_buff)
 
 
 @dataclass
@@ -57,6 +58,10 @@ class StartupMessage:
             options=d.get('options', '')
         )
 
+    @classmethod
+    def read_from_buff(cls, _inner_buff):
+        pass
+
 
 @dataclass
 class PasswordMessage:
